@@ -1,5 +1,5 @@
 # Tests of DSE curvature functions from dsecurvature.function.testsA
- require("dse2"); require("curve") #,  warn.conflicts=F)
+ require("dse2"); require("curve") #,  warn.conflicts=FALSE)
  Sys.info()
  version.dse()
  
@@ -7,7 +7,7 @@ fuzz.small <- 1e-12
 fuzz.large <- 1e-6
 fuzz.very.large <- 1e-2
 digits <- 18
-all.ok <- T
+all.ok <- TRUE
 test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Muller")
 
 
@@ -47,7 +47,7 @@ test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Mul
    {c(l(set.arrays(Shape,coefficients=coefficients),data,result="pred")
         - output.data(data))}, coef(VARmodel), 
                   func.args=list(Shape=TSmodel(VARmodel),data=TSdata(VARmodel)),
-                     d=0.01, eps=1e-4,r=6, show.details=F)$stats
+                     d=0.01, eps=1e-4,r=6, show.details=FALSE)$stats
 
 
    tst  <-  curvatureVAR.def
