@@ -8,7 +8,7 @@
 # change much (as would be hoped) but do change more than the tolerance of 
 # these tests. Old values in comments are  strictly for historical reference.
 
- require("dse2"); require("curve") #,  warn.conflicts=F)
+ require("dse2"); require("curve") #,  warn.conflicts=FALSE)
  Sys.info()
  version.dse()
 
@@ -28,7 +28,7 @@ all.ok <- T
    input.data(data) <- NULL
   output.data(data) <- output.data(data)[1:50,1:2]
 
-  VARmodel <- est.VARX.ls(data, re.add.means=F)
+  VARmodel <- est.VARX.ls(data, re.add.means=FALSE)
   SSmodel  <- l(to.SS(VARmodel),  data)
   ARMAmodel<- l(to.ARMA(SSmodel), data)
 
